@@ -1,8 +1,6 @@
 import hashlib
 from typing import List, Mapping, Optional, Union
 
-from attr import define, asdict
-
 from webauthn.helpers import (
     aaguid_to_string,
     bytes_to_base64url,
@@ -18,6 +16,8 @@ from webauthn.helpers.structs import (
     PublicKeyCredentialType,
     RegistrationCredential,
     TokenBindingStatus,
+    WebAuthnBaseModel,
+    BytesLike,
 )
 from .formats.android_key import verify_android_key
 from .formats.android_safetynet import verify_android_safetynet
@@ -28,8 +28,7 @@ from .formats.tpm import verify_tpm
 from .generate_registration_options import default_supported_pub_key_algs
 
 
-@define
-class VerifiedRegistration:
+class VerifiedRegistration(WebAuthnBaseModel):
     """Information about a verified attestation of which an RP can make use.
 
     Attributes:
@@ -43,14 +42,14 @@ class VerifiedRegistration:
         `attestation_object`: The raw attestation object for later scrutiny
     """
 
-    credential_id: bytes
-    credential_public_key: bytes
+    credential_id: BytesLike
+    credential_public_key: BytesLike
     sign_count: int
     aaguid: str
     fmt: AttestationFormat
     credential_type: PublicKeyCredentialType
     user_verified: bool
-    attestation_object: bytes
+    attestation_object: BytesLike
 
 
 expected_token_binding_statuses = [
@@ -196,12 +195,8 @@ def verify_registration_response(
     if attestation_object.fmt == AttestationFormat.NONE:
         # A "none" attestation should not contain _anything_ in its attestation
         # statement
-        num_att_stmt_fields_set = [
-            val
-            for _, val in asdict(attestation_object.att_stmt).items()
-            if val is not None
-        ]
-        if len(num_att_stmt_fields_set) > 0:
+        num_att_stmt_fields_set = len(attestation_object.att_stmt.__fields_set__)
+        if num_att_stmt_fields_set > 0:
             raise InvalidRegistrationResponse(
                 "None attestation had unexpected attestation statement"
             )
